from typing import List
from pyVmomi import eam, vmodl
from datetime import datetime


class VibInfo(vmodl.DynamicData):
    @property
    def id(self) -> str: ...
    @id.setter
    def id(self, value: str):
        self._id = value
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def version(self) -> str: ...
    @version.setter
    def version(self, value: str):
        self._version = value
    @property
    def vendor(self) -> str: ...
    @vendor.setter
    def vendor(self, value: str):
        self._vendor = value
    @property
    def summary(self) -> str: ...
    @summary.setter
    def summary(self, value: str):
        self._summary = value
    @property
    def softwareTags(self) -> VibInfo.SoftwareTags: ...
    @softwareTags.setter
    def softwareTags(self, value: VibInfo.SoftwareTags):
        self._softwareTags = value
    @property
    def releaseDate(self) -> datetime: ...
    @releaseDate.setter
    def releaseDate(self, value: datetime):
        self._releaseDate = value


    class SoftwareTags(vmodl.DynamicData):
        @property
        def tags(self) -> List[str]: ...
        @tags.setter
        def tags(self, value: List[str]):
            self._tags = value


class VibServices():


    class AnyCertificate(VibServices.SslTrust): ...


    class PinnedPemCertificate(VibServices.SslTrust):
        @property
        def sslCertificate(self) -> str: ...
        @sslCertificate.setter
        def sslCertificate(self, value: str):
            self._sslCertificate = value


    class SslTrust(vmodl.DynamicData): ...


# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******
from .VmomiSupport import CreateDataType, CreateManagedType
from .VmomiSupport import CreateEnumType
from .VmomiSupport import AddVersion, AddVersionParent
from .VmomiSupport import AddBreakingChangesInfo
from .VmomiSupport import F_LINK, F_LINKABLE
from .VmomiSupport import F_OPTIONAL, F_SECRET
from .VmomiSupport import newestVersions, ltsVersions
from .VmomiSupport import dottedVersions, oldestVersions

AddVersion("vim.version.v8_0_2_0", "vim25", "8.0.2.0", 0, "vim25")
AddVersion("vmodl.query.version.version4", "", "", 0, "vim25")
AddVersion("vmodl.query.version.version3", "", "", 0, "vim25")
AddVersion("vmodl.query.version.version2", "", "", 0, "vim25")
AddVersion("vmodl.query.version.version1", "", "", 0, "vim25")
AddVersion("vim.version.version8", "vim25", "5.1", 0, "vim25")
AddVersion("vim.version.version9", "vim25", "5.5", 0, "vim25")
AddVersion("vim.version.version6", "vim25", "4.1", 0, "vim25")
AddVersion("vim.version.version7", "vim25", "5.0", 0, "vim25")
AddVersion("vim.version.version1", "vim2", "2.0", 0, "vim25")
AddVersion("vim.version.v7_0_1_1", "vim25", "7.0.1.1", 0, "vim25")
AddVersion("vim.version.version4", "vim25", "2.5u2server", 0, "vim25")
AddVersion("vim.version.version5", "vim25", "4.0", 0, "vim25")
AddVersion("vim.version.version2", "vim25", "2.5", 0, "vim25")
AddVersion("vim.version.version3", "vim25", "2.5u2", 0, "vim25")
AddVersion("vslm.version.version1", "vslm", "1.0", 0, "vslm")
AddVersion("vslm.version.v7_0_1_0", "vslm", "7.0.1.0", 0, "vslm")
AddVersion("vmodl.version.version0", "", "", 0, "vim25")
AddVersion("vmodl.version.version1", "", "", 0, "vim25")
AddVersion("vmodl.version.version2", "", "", 0, "vim25")
AddVersion("vim.version.v6_9_1", "vim25", "6.9.1", 0, "vim25")
AddVersion("vim.version.v8_0_1_0", "vim25", "8.0.1.0", 0, "vim25")
AddVersion("vim.version.v7_0_0_2", "vim25", "7.0.0.2", 0, "vim25")
AddVersion("vim.version.v6_8_7", "vim25", "6.8.7", 0, "vim25")
AddVersion("vmodl.reflect.version.version1", "reflect", "1.0", 0, "reflect")
AddVersion("vmodl.reflect.version.version2", "reflect", "2.0", 0, "reflect")
AddVersion("vim.version.v8_0_0_0", "vim25", "8.0.0.0", 0, "vim25")
AddVersion("vim.version.v8_0_0_1", "vim25", "8.0.0.1", 0, "vim25")
AddVersion("vim.version.v8_0_0_2", "vim25", "8.0.0.2", 0, "vim25")
AddVersion("vim.version.v7_0_3_1", "vim25", "7.0.3.1", 0, "vim25")
AddVersion("vim.version.v7_0_3_2", "vim25", "7.0.3.2", 0, "vim25")
AddVersion("vslm.version.version15", "vslm", "6.7.3", 0, "vslm")
AddVersion("vslm.version.version14", "vslm", "6.7.2", 0, "vslm")
AddVersion("vim.version.v7_0_3_0", "vim25", "7.0.3.0", 0, "vim25")
AddVersion("vim.version.version13", "vim25", "6.7.1", 0, "vim25")
AddVersion("vim.version.version14", "vim25", "6.7.2", 0, "vim25")
AddVersion("vim.version.version15", "vim25", "6.7.3", 0, "vim25")
AddVersion("vslm.version.v7_0", "vslm", "7.0.0.0", 0, "vslm")
AddVersion("vim.version.version10", "vim25", "6.0", 0, "vim25")
AddVersion("vim.version.version11", "vim25", "6.5", 0, "vim25")
AddVersion("vim.version.version12", "vim25", "6.7", 0, "vim25")
AddVersion("vim.version.v7_0_2_0", "vim25", "7.0.2.0", 0, "vim25")
AddVersion("vim.version.v7_0_2_1", "vim25", "7.0.2.1", 0, "vim25")
AddVersion("vim.version.v7_0_1_0", "vim25", "7.0.1.0", 0, "vim25")
AddVersion("vslm.version.v7_0_2_0", "vslm", "7.0.2.0", 0, "vslm")
AddVersion("vim.version.v7_0", "vim25", "7.0.0.0", 0, "vim25")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_2_0")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version8")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version9")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version6")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version7")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version4")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version5")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version3")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_1_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_2_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v8_0_0_2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version13")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version14")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version15")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version10")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version11")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.version12")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_2_0", "vim.version.v7_0")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version4")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version3")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version2")
AddVersionParent("vmodl.query.version.version4", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version4", "vmodl.version.version0")
AddVersionParent("vmodl.query.version.version4", "vmodl.version.version1")
AddVersionParent("vmodl.query.version.version4", "vmodl.version.version2")
AddVersionParent("vmodl.query.version.version3", "vmodl.query.version.version3")
AddVersionParent("vmodl.query.version.version3", "vmodl.query.version.version2")
AddVersionParent("vmodl.query.version.version3", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version3", "vmodl.version.version0")
AddVersionParent("vmodl.query.version.version3", "vmodl.version.version1")
AddVersionParent("vmodl.query.version.version2", "vmodl.query.version.version2")
AddVersionParent("vmodl.query.version.version2", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.query.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.query.version.version1", "vmodl.query.version.version1")
AddVersionParent("vmodl.query.version.version1", "vmodl.version.version0")
AddVersionParent("vim.version.version8", "vmodl.query.version.version4")
AddVersionParent("vim.version.version8", "vmodl.query.version.version3")
AddVersionParent("vim.version.version8", "vmodl.query.version.version2")
AddVersionParent("vim.version.version8", "vmodl.query.version.version1")
AddVersionParent("vim.version.version8", "vim.version.version8")
AddVersionParent("vim.version.version8", "vim.version.version6")
AddVersionParent("vim.version.version8", "vim.version.version7")
AddVersionParent("vim.version.version8", "vim.version.version1")
AddVersionParent("vim.version.version8", "vim.version.version4")
AddVersionParent("vim.version.version8", "vim.version.version5")
AddVersionParent("vim.version.version8", "vim.version.version2")
AddVersionParent("vim.version.version8", "vim.version.version3")
AddVersionParent("vim.version.version8", "vmodl.version.version0")
AddVersionParent("vim.version.version8", "vmodl.version.version1")
AddVersionParent("vim.version.version8", "vmodl.version.version2")
AddVersionParent("vim.version.version8", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version9", "vmodl.query.version.version4")
AddVersionParent("vim.version.version9", "vmodl.query.version.version3")
AddVersionParent("vim.version.version9", "vmodl.query.version.version2")
AddVersionParent("vim.version.version9", "vmodl.query.version.version1")
AddVersionParent("vim.version.version9", "vim.version.version8")
AddVersionParent("vim.version.version9", "vim.version.version9")
AddVersionParent("vim.version.version9", "vim.version.version6")
AddVersionParent("vim.version.version9", "vim.version.version7")
AddVersionParent("vim.version.version9", "vim.version.version1")
AddVersionParent("vim.version.version9", "vim.version.version4")
AddVersionParent("vim.version.version9", "vim.version.version5")
AddVersionParent("vim.version.version9", "vim.version.version2")
AddVersionParent("vim.version.version9", "vim.version.version3")
AddVersionParent("vim.version.version9", "vmodl.version.version0")
AddVersionParent("vim.version.version9", "vmodl.version.version1")
AddVersionParent("vim.version.version9", "vmodl.version.version2")
AddVersionParent("vim.version.version9", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version6", "vmodl.query.version.version3")
AddVersionParent("vim.version.version6", "vmodl.query.version.version2")
AddVersionParent("vim.version.version6", "vmodl.query.version.version1")
AddVersionParent("vim.version.version6", "vim.version.version6")
AddVersionParent("vim.version.version6", "vim.version.version1")
AddVersionParent("vim.version.version6", "vim.version.version4")
AddVersionParent("vim.version.version6", "vim.version.version5")
AddVersionParent("vim.version.version6", "vim.version.version2")
AddVersionParent("vim.version.version6", "vim.version.version3")
AddVersionParent("vim.version.version6", "vmodl.version.version0")
AddVersionParent("vim.version.version6", "vmodl.version.version1")
AddVersionParent("vim.version.version7", "vmodl.query.version.version4")
AddVersionParent("vim.version.version7", "vmodl.query.version.version3")
AddVersionParent("vim.version.version7", "vmodl.query.version.version2")
AddVersionParent("vim.version.version7", "vmodl.query.version.version1")
AddVersionParent("vim.version.version7", "vim.version.version6")
AddVersionParent("vim.version.version7", "vim.version.version7")
AddVersionParent("vim.version.version7", "vim.version.version1")
AddVersionParent("vim.version.version7", "vim.version.version4")
AddVersionParent("vim.version.version7", "vim.version.version5")
AddVersionParent("vim.version.version7", "vim.version.version2")
AddVersionParent("vim.version.version7", "vim.version.version3")
AddVersionParent("vim.version.version7", "vmodl.version.version0")
AddVersionParent("vim.version.version7", "vmodl.version.version1")
AddVersionParent("vim.version.version7", "vmodl.version.version2")
AddVersionParent("vim.version.version7", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version1", "vmodl.query.version.version1")
AddVersionParent("vim.version.version1", "vim.version.version1")
AddVersionParent("vim.version.version1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version8")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version9")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version6")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version7")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version4")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version5")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version3")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_1_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version13")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version14")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version15")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version10")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version11")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.version12")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_1_1", "vim.version.v7_0")
AddVersionParent("vim.version.version4", "vmodl.query.version.version1")
AddVersionParent("vim.version.version4", "vim.version.version1")
AddVersionParent("vim.version.version4", "vim.version.version4")
AddVersionParent("vim.version.version4", "vim.version.version2")
AddVersionParent("vim.version.version4", "vim.version.version3")
AddVersionParent("vim.version.version4", "vmodl.version.version0")
AddVersionParent("vim.version.version5", "vmodl.query.version.version2")
AddVersionParent("vim.version.version5", "vmodl.query.version.version1")
AddVersionParent("vim.version.version5", "vim.version.version1")
AddVersionParent("vim.version.version5", "vim.version.version4")
AddVersionParent("vim.version.version5", "vim.version.version5")
AddVersionParent("vim.version.version5", "vim.version.version2")
AddVersionParent("vim.version.version5", "vim.version.version3")
AddVersionParent("vim.version.version5", "vmodl.version.version0")
AddVersionParent("vim.version.version5", "vmodl.version.version1")
AddVersionParent("vim.version.version2", "vmodl.query.version.version1")
AddVersionParent("vim.version.version2", "vim.version.version1")
AddVersionParent("vim.version.version2", "vim.version.version2")
AddVersionParent("vim.version.version2", "vmodl.version.version0")
AddVersionParent("vim.version.version3", "vmodl.query.version.version1")
AddVersionParent("vim.version.version3", "vim.version.version1")
AddVersionParent("vim.version.version3", "vim.version.version2")
AddVersionParent("vim.version.version3", "vim.version.version3")
AddVersionParent("vim.version.version3", "vmodl.version.version0")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version4")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version3")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version2")
AddVersionParent("vslm.version.version1", "vmodl.query.version.version1")
AddVersionParent("vslm.version.version1", "vim.version.version8")
AddVersionParent("vslm.version.version1", "vim.version.version9")
AddVersionParent("vslm.version.version1", "vim.version.version6")
AddVersionParent("vslm.version.version1", "vim.version.version7")
AddVersionParent("vslm.version.version1", "vim.version.version1")
AddVersionParent("vslm.version.version1", "vim.version.version4")
AddVersionParent("vslm.version.version1", "vim.version.version5")
AddVersionParent("vslm.version.version1", "vim.version.version2")
AddVersionParent("vslm.version.version1", "vim.version.version3")
AddVersionParent("vslm.version.version1", "vslm.version.version1")
AddVersionParent("vslm.version.version1", "vmodl.version.version0")
AddVersionParent("vslm.version.version1", "vmodl.version.version1")
AddVersionParent("vslm.version.version1", "vmodl.version.version2")
AddVersionParent("vslm.version.version1", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.version1", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.version1", "vim.version.version10")
AddVersionParent("vslm.version.version1", "vim.version.version11")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version4")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version3")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.query.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version8")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version9")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version6")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version7")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version4")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version5")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version3")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.version.version0")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v6_9_1")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v7_0_0_2")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v6_8_7")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.v7_0_1_0", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.version15")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.version14")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version13")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version14")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version15")
AddVersionParent("vslm.version.v7_0_1_0", "vslm.version.v7_0")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version10")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version11")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.version12")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_1_0", "vim.version.v7_0")
AddVersionParent("vmodl.version.version0", "vmodl.version.version0")
AddVersionParent("vmodl.version.version1", "vmodl.version.version0")
AddVersionParent("vmodl.version.version1", "vmodl.version.version1")
AddVersionParent("vmodl.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.version.version2", "vmodl.version.version2")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v6_9_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v6_9_1", "vim.version.version8")
AddVersionParent("vim.version.v6_9_1", "vim.version.version9")
AddVersionParent("vim.version.v6_9_1", "vim.version.version6")
AddVersionParent("vim.version.v6_9_1", "vim.version.version7")
AddVersionParent("vim.version.v6_9_1", "vim.version.version1")
AddVersionParent("vim.version.v6_9_1", "vim.version.version4")
AddVersionParent("vim.version.v6_9_1", "vim.version.version5")
AddVersionParent("vim.version.v6_9_1", "vim.version.version2")
AddVersionParent("vim.version.v6_9_1", "vim.version.version3")
AddVersionParent("vim.version.v6_9_1", "vmodl.version.version0")
AddVersionParent("vim.version.v6_9_1", "vmodl.version.version1")
AddVersionParent("vim.version.v6_9_1", "vmodl.version.version2")
AddVersionParent("vim.version.v6_9_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v6_9_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v6_9_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v6_9_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v6_9_1", "vim.version.version13")
AddVersionParent("vim.version.v6_9_1", "vim.version.version14")
AddVersionParent("vim.version.v6_9_1", "vim.version.version15")
AddVersionParent("vim.version.v6_9_1", "vim.version.version10")
AddVersionParent("vim.version.v6_9_1", "vim.version.version11")
AddVersionParent("vim.version.v6_9_1", "vim.version.version12")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version8")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version9")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version6")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version7")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version4")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version5")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version3")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_1_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_1_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v8_0_0_2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version13")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version14")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version15")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version10")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version11")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.version12")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_1_0", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version8")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version9")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version6")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version7")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version4")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version5")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version3")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_0_2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version13")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version14")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version15")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version10")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version11")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.version12")
AddVersionParent("vim.version.v7_0_0_2", "vim.version.v7_0")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version4")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version3")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version2")
AddVersionParent("vim.version.v6_8_7", "vmodl.query.version.version1")
AddVersionParent("vim.version.v6_8_7", "vim.version.version8")
AddVersionParent("vim.version.v6_8_7", "vim.version.version9")
AddVersionParent("vim.version.v6_8_7", "vim.version.version6")
AddVersionParent("vim.version.v6_8_7", "vim.version.version7")
AddVersionParent("vim.version.v6_8_7", "vim.version.version1")
AddVersionParent("vim.version.v6_8_7", "vim.version.version4")
AddVersionParent("vim.version.v6_8_7", "vim.version.version5")
AddVersionParent("vim.version.v6_8_7", "vim.version.version2")
AddVersionParent("vim.version.v6_8_7", "vim.version.version3")
AddVersionParent("vim.version.v6_8_7", "vmodl.version.version0")
AddVersionParent("vim.version.v6_8_7", "vmodl.version.version1")
AddVersionParent("vim.version.v6_8_7", "vmodl.version.version2")
AddVersionParent("vim.version.v6_8_7", "vim.version.v6_8_7")
AddVersionParent("vim.version.v6_8_7", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v6_8_7", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v6_8_7", "vim.version.version13")
AddVersionParent("vim.version.v6_8_7", "vim.version.version14")
AddVersionParent("vim.version.v6_8_7", "vim.version.version15")
AddVersionParent("vim.version.v6_8_7", "vim.version.version10")
AddVersionParent("vim.version.v6_8_7", "vim.version.version11")
AddVersionParent("vim.version.v6_8_7", "vim.version.version12")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.version.version0")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.version.version1")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.version.version2")
AddVersionParent("vmodl.reflect.version.version1", "vmodl.reflect.version.version1")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.version.version0")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.version.version1")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.version.version2")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.reflect.version.version1")
AddVersionParent("vmodl.reflect.version.version2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version8")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version9")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version6")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version7")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version4")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version5")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version3")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_0_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version13")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version14")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version15")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version10")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version11")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.version12")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_0_0", "vim.version.v7_0")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version8")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version9")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version6")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version7")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version4")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version5")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version3")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_0_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version13")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version14")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version15")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version10")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version11")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.version12")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_0_1", "vim.version.v7_0")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version4")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version3")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.query.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version8")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version9")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version6")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version7")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version4")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version5")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version3")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.version.version0")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v6_9_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v6_8_7")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v8_0_0_2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v8_0_0_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v8_0_0_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v8_0_0_2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version13")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version14")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version15")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version10")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version11")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.version12")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v8_0_0_2", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version8")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version9")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version6")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version7")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version4")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version5")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version3")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_3_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version13")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version14")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version15")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version10")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version11")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_3_1", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version8")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version9")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version6")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version7")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version4")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version5")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version3")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_3_2", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_3_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_3_2")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version13")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version14")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version15")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version10")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version11")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_3_2", "vim.version.v7_0")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version4")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version3")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version2")
AddVersionParent("vslm.version.version15", "vmodl.query.version.version1")
AddVersionParent("vslm.version.version15", "vim.version.version8")
AddVersionParent("vslm.version.version15", "vim.version.version9")
AddVersionParent("vslm.version.version15", "vim.version.version6")
AddVersionParent("vslm.version.version15", "vim.version.version7")
AddVersionParent("vslm.version.version15", "vim.version.version1")
AddVersionParent("vslm.version.version15", "vim.version.version4")
AddVersionParent("vslm.version.version15", "vim.version.version5")
AddVersionParent("vslm.version.version15", "vim.version.version2")
AddVersionParent("vslm.version.version15", "vim.version.version3")
AddVersionParent("vslm.version.version15", "vslm.version.version1")
AddVersionParent("vslm.version.version15", "vmodl.version.version0")
AddVersionParent("vslm.version.version15", "vmodl.version.version1")
AddVersionParent("vslm.version.version15", "vmodl.version.version2")
AddVersionParent("vslm.version.version15", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.version15", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.version15", "vslm.version.version15")
AddVersionParent("vslm.version.version15", "vslm.version.version14")
AddVersionParent("vslm.version.version15", "vim.version.version13")
AddVersionParent("vslm.version.version15", "vim.version.version14")
AddVersionParent("vslm.version.version15", "vim.version.version15")
AddVersionParent("vslm.version.version15", "vim.version.version10")
AddVersionParent("vslm.version.version15", "vim.version.version11")
AddVersionParent("vslm.version.version15", "vim.version.version12")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version4")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version3")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version2")
AddVersionParent("vslm.version.version14", "vmodl.query.version.version1")
AddVersionParent("vslm.version.version14", "vim.version.version8")
AddVersionParent("vslm.version.version14", "vim.version.version9")
AddVersionParent("vslm.version.version14", "vim.version.version6")
AddVersionParent("vslm.version.version14", "vim.version.version7")
AddVersionParent("vslm.version.version14", "vim.version.version1")
AddVersionParent("vslm.version.version14", "vim.version.version4")
AddVersionParent("vslm.version.version14", "vim.version.version5")
AddVersionParent("vslm.version.version14", "vim.version.version2")
AddVersionParent("vslm.version.version14", "vim.version.version3")
AddVersionParent("vslm.version.version14", "vslm.version.version1")
AddVersionParent("vslm.version.version14", "vmodl.version.version0")
AddVersionParent("vslm.version.version14", "vmodl.version.version1")
AddVersionParent("vslm.version.version14", "vmodl.version.version2")
AddVersionParent("vslm.version.version14", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.version14", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.version14", "vslm.version.version14")
AddVersionParent("vslm.version.version14", "vim.version.version13")
AddVersionParent("vslm.version.version14", "vim.version.version14")
AddVersionParent("vslm.version.version14", "vim.version.version10")
AddVersionParent("vslm.version.version14", "vim.version.version11")
AddVersionParent("vslm.version.version14", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_3_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_3_0")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_3_0", "vim.version.v7_0")
AddVersionParent("vim.version.version13", "vmodl.query.version.version4")
AddVersionParent("vim.version.version13", "vmodl.query.version.version3")
AddVersionParent("vim.version.version13", "vmodl.query.version.version2")
AddVersionParent("vim.version.version13", "vmodl.query.version.version1")
AddVersionParent("vim.version.version13", "vim.version.version8")
AddVersionParent("vim.version.version13", "vim.version.version9")
AddVersionParent("vim.version.version13", "vim.version.version6")
AddVersionParent("vim.version.version13", "vim.version.version7")
AddVersionParent("vim.version.version13", "vim.version.version1")
AddVersionParent("vim.version.version13", "vim.version.version4")
AddVersionParent("vim.version.version13", "vim.version.version5")
AddVersionParent("vim.version.version13", "vim.version.version2")
AddVersionParent("vim.version.version13", "vim.version.version3")
AddVersionParent("vim.version.version13", "vmodl.version.version0")
AddVersionParent("vim.version.version13", "vmodl.version.version1")
AddVersionParent("vim.version.version13", "vmodl.version.version2")
AddVersionParent("vim.version.version13", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version13", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version13", "vim.version.version13")
AddVersionParent("vim.version.version13", "vim.version.version10")
AddVersionParent("vim.version.version13", "vim.version.version11")
AddVersionParent("vim.version.version13", "vim.version.version12")
AddVersionParent("vim.version.version14", "vmodl.query.version.version4")
AddVersionParent("vim.version.version14", "vmodl.query.version.version3")
AddVersionParent("vim.version.version14", "vmodl.query.version.version2")
AddVersionParent("vim.version.version14", "vmodl.query.version.version1")
AddVersionParent("vim.version.version14", "vim.version.version8")
AddVersionParent("vim.version.version14", "vim.version.version9")
AddVersionParent("vim.version.version14", "vim.version.version6")
AddVersionParent("vim.version.version14", "vim.version.version7")
AddVersionParent("vim.version.version14", "vim.version.version1")
AddVersionParent("vim.version.version14", "vim.version.version4")
AddVersionParent("vim.version.version14", "vim.version.version5")
AddVersionParent("vim.version.version14", "vim.version.version2")
AddVersionParent("vim.version.version14", "vim.version.version3")
AddVersionParent("vim.version.version14", "vmodl.version.version0")
AddVersionParent("vim.version.version14", "vmodl.version.version1")
AddVersionParent("vim.version.version14", "vmodl.version.version2")
AddVersionParent("vim.version.version14", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version14", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version14", "vim.version.version13")
AddVersionParent("vim.version.version14", "vim.version.version14")
AddVersionParent("vim.version.version14", "vim.version.version10")
AddVersionParent("vim.version.version14", "vim.version.version11")
AddVersionParent("vim.version.version14", "vim.version.version12")
AddVersionParent("vim.version.version15", "vmodl.query.version.version4")
AddVersionParent("vim.version.version15", "vmodl.query.version.version3")
AddVersionParent("vim.version.version15", "vmodl.query.version.version2")
AddVersionParent("vim.version.version15", "vmodl.query.version.version1")
AddVersionParent("vim.version.version15", "vim.version.version8")
AddVersionParent("vim.version.version15", "vim.version.version9")
AddVersionParent("vim.version.version15", "vim.version.version6")
AddVersionParent("vim.version.version15", "vim.version.version7")
AddVersionParent("vim.version.version15", "vim.version.version1")
AddVersionParent("vim.version.version15", "vim.version.version4")
AddVersionParent("vim.version.version15", "vim.version.version5")
AddVersionParent("vim.version.version15", "vim.version.version2")
AddVersionParent("vim.version.version15", "vim.version.version3")
AddVersionParent("vim.version.version15", "vmodl.version.version0")
AddVersionParent("vim.version.version15", "vmodl.version.version1")
AddVersionParent("vim.version.version15", "vmodl.version.version2")
AddVersionParent("vim.version.version15", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version15", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version15", "vim.version.version13")
AddVersionParent("vim.version.version15", "vim.version.version14")
AddVersionParent("vim.version.version15", "vim.version.version15")
AddVersionParent("vim.version.version15", "vim.version.version10")
AddVersionParent("vim.version.version15", "vim.version.version11")
AddVersionParent("vim.version.version15", "vim.version.version12")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version4")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version3")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version2")
AddVersionParent("vslm.version.v7_0", "vmodl.query.version.version1")
AddVersionParent("vslm.version.v7_0", "vim.version.version8")
AddVersionParent("vslm.version.v7_0", "vim.version.version9")
AddVersionParent("vslm.version.v7_0", "vim.version.version6")
AddVersionParent("vslm.version.v7_0", "vim.version.version7")
AddVersionParent("vslm.version.v7_0", "vim.version.version1")
AddVersionParent("vslm.version.v7_0", "vim.version.version4")
AddVersionParent("vslm.version.v7_0", "vim.version.version5")
AddVersionParent("vslm.version.v7_0", "vim.version.version2")
AddVersionParent("vslm.version.v7_0", "vim.version.version3")
AddVersionParent("vslm.version.v7_0", "vslm.version.version1")
AddVersionParent("vslm.version.v7_0", "vmodl.version.version0")
AddVersionParent("vslm.version.v7_0", "vmodl.version.version1")
AddVersionParent("vslm.version.v7_0", "vmodl.version.version2")
AddVersionParent("vslm.version.v7_0", "vim.version.v6_9_1")
AddVersionParent("vslm.version.v7_0", "vim.version.v6_8_7")
AddVersionParent("vslm.version.v7_0", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.v7_0", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.v7_0", "vslm.version.version15")
AddVersionParent("vslm.version.v7_0", "vslm.version.version14")
AddVersionParent("vslm.version.v7_0", "vim.version.version13")
AddVersionParent("vslm.version.v7_0", "vim.version.version14")
AddVersionParent("vslm.version.v7_0", "vim.version.version15")
AddVersionParent("vslm.version.v7_0", "vslm.version.v7_0")
AddVersionParent("vslm.version.v7_0", "vim.version.version10")
AddVersionParent("vslm.version.v7_0", "vim.version.version11")
AddVersionParent("vslm.version.v7_0", "vim.version.version12")
AddVersionParent("vslm.version.v7_0", "vim.version.v7_0")
AddVersionParent("vim.version.version10", "vmodl.query.version.version4")
AddVersionParent("vim.version.version10", "vmodl.query.version.version3")
AddVersionParent("vim.version.version10", "vmodl.query.version.version2")
AddVersionParent("vim.version.version10", "vmodl.query.version.version1")
AddVersionParent("vim.version.version10", "vim.version.version8")
AddVersionParent("vim.version.version10", "vim.version.version9")
AddVersionParent("vim.version.version10", "vim.version.version6")
AddVersionParent("vim.version.version10", "vim.version.version7")
AddVersionParent("vim.version.version10", "vim.version.version1")
AddVersionParent("vim.version.version10", "vim.version.version4")
AddVersionParent("vim.version.version10", "vim.version.version5")
AddVersionParent("vim.version.version10", "vim.version.version2")
AddVersionParent("vim.version.version10", "vim.version.version3")
AddVersionParent("vim.version.version10", "vmodl.version.version0")
AddVersionParent("vim.version.version10", "vmodl.version.version1")
AddVersionParent("vim.version.version10", "vmodl.version.version2")
AddVersionParent("vim.version.version10", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version10", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version10", "vim.version.version10")
AddVersionParent("vim.version.version11", "vmodl.query.version.version4")
AddVersionParent("vim.version.version11", "vmodl.query.version.version3")
AddVersionParent("vim.version.version11", "vmodl.query.version.version2")
AddVersionParent("vim.version.version11", "vmodl.query.version.version1")
AddVersionParent("vim.version.version11", "vim.version.version8")
AddVersionParent("vim.version.version11", "vim.version.version9")
AddVersionParent("vim.version.version11", "vim.version.version6")
AddVersionParent("vim.version.version11", "vim.version.version7")
AddVersionParent("vim.version.version11", "vim.version.version1")
AddVersionParent("vim.version.version11", "vim.version.version4")
AddVersionParent("vim.version.version11", "vim.version.version5")
AddVersionParent("vim.version.version11", "vim.version.version2")
AddVersionParent("vim.version.version11", "vim.version.version3")
AddVersionParent("vim.version.version11", "vmodl.version.version0")
AddVersionParent("vim.version.version11", "vmodl.version.version1")
AddVersionParent("vim.version.version11", "vmodl.version.version2")
AddVersionParent("vim.version.version11", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version11", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version11", "vim.version.version10")
AddVersionParent("vim.version.version11", "vim.version.version11")
AddVersionParent("vim.version.version12", "vmodl.query.version.version4")
AddVersionParent("vim.version.version12", "vmodl.query.version.version3")
AddVersionParent("vim.version.version12", "vmodl.query.version.version2")
AddVersionParent("vim.version.version12", "vmodl.query.version.version1")
AddVersionParent("vim.version.version12", "vim.version.version8")
AddVersionParent("vim.version.version12", "vim.version.version9")
AddVersionParent("vim.version.version12", "vim.version.version6")
AddVersionParent("vim.version.version12", "vim.version.version7")
AddVersionParent("vim.version.version12", "vim.version.version1")
AddVersionParent("vim.version.version12", "vim.version.version4")
AddVersionParent("vim.version.version12", "vim.version.version5")
AddVersionParent("vim.version.version12", "vim.version.version2")
AddVersionParent("vim.version.version12", "vim.version.version3")
AddVersionParent("vim.version.version12", "vmodl.version.version0")
AddVersionParent("vim.version.version12", "vmodl.version.version1")
AddVersionParent("vim.version.version12", "vmodl.version.version2")
AddVersionParent("vim.version.version12", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.version12", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.version12", "vim.version.version10")
AddVersionParent("vim.version.version12", "vim.version.version11")
AddVersionParent("vim.version.version12", "vim.version.version12")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_2_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_2_0", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version8")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version9")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version6")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version7")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_1_1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version4")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version5")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version3")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_2_1", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version13")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version14")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version15")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version10")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version11")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.version12")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_2_0")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_2_1")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_2_1", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v7_0_0_2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0_1_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v7_0_1_0")
AddVersionParent("vim.version.v7_0_1_0", "vim.version.v7_0")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version4")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version3")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.query.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version8")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version9")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version6")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version7")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_1_1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version4")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version5")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version3")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.version.version0")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v6_9_1")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_0_2")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v6_8_7")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.reflect.version.version1")
AddVersionParent("vslm.version.v7_0_2_0", "vmodl.reflect.version.version2")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.version15")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.version14")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version13")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version14")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version15")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.v7_0")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version10")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version11")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.version12")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_2_0")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0_1_0")
AddVersionParent("vslm.version.v7_0_2_0", "vslm.version.v7_0_2_0")
AddVersionParent("vslm.version.v7_0_2_0", "vim.version.v7_0")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version4")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version3")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version2")
AddVersionParent("vim.version.v7_0", "vmodl.query.version.version1")
AddVersionParent("vim.version.v7_0", "vim.version.version8")
AddVersionParent("vim.version.v7_0", "vim.version.version9")
AddVersionParent("vim.version.v7_0", "vim.version.version6")
AddVersionParent("vim.version.v7_0", "vim.version.version7")
AddVersionParent("vim.version.v7_0", "vim.version.version1")
AddVersionParent("vim.version.v7_0", "vim.version.version4")
AddVersionParent("vim.version.v7_0", "vim.version.version5")
AddVersionParent("vim.version.v7_0", "vim.version.version2")
AddVersionParent("vim.version.v7_0", "vim.version.version3")
AddVersionParent("vim.version.v7_0", "vmodl.version.version0")
AddVersionParent("vim.version.v7_0", "vmodl.version.version1")
AddVersionParent("vim.version.v7_0", "vmodl.version.version2")
AddVersionParent("vim.version.v7_0", "vim.version.v6_9_1")
AddVersionParent("vim.version.v7_0", "vim.version.v6_8_7")
AddVersionParent("vim.version.v7_0", "vmodl.reflect.version.version1")
AddVersionParent("vim.version.v7_0", "vmodl.reflect.version.version2")
AddVersionParent("vim.version.v7_0", "vim.version.version13")
AddVersionParent("vim.version.v7_0", "vim.version.version14")
AddVersionParent("vim.version.v7_0", "vim.version.version15")
AddVersionParent("vim.version.v7_0", "vim.version.version10")
AddVersionParent("vim.version.v7_0", "vim.version.version11")
AddVersionParent("vim.version.v7_0", "vim.version.version12")
AddVersionParent("vim.version.v7_0", "vim.version.v7_0")

newestVersions.Add("vslm.version.v7_0_2_0")
ltsVersions.Add("vslm.version.v7_0_2_0")
dottedVersions.Add("vslm.version.v7_0_2_0")
oldestVersions.Add("vslm.version.version1")

CreateDataType("vslm.AboutInfo", "VslmAboutInfo", "vmodl.DynamicData", "vslm.version.version1", [("name", "string", "vslm.version.version1", 0), ("fullName", "string", "vslm.version.version1", 0), ("vendor", "string", "vslm.version.version1", 0), ("apiVersion", "string", "vslm.version.version1", 0), ("instanceUuid", "string", "vslm.version.version1", 0)])
CreateDataType("vslm.QueryDatastoreInfoResult", "VslmQueryDatastoreInfoResult", "vmodl.DynamicData", "vslm.version.version14", [("datacenter", "vim.Datacenter", "vslm.version.version14", 0), ("datastore", "vim.Datastore", "vslm.version.version14", 0)])
CreateManagedType("vslm.ServiceInstance", "VslmServiceInstance", "vmodl.ManagedObject", "vslm.version.version14", [("content", "vslm.ServiceInstanceContent", "vslm.version.version14", 0, "System.Anonymous")], [("retrieveContent", "RetrieveContent", "vslm.version.version14", (), (0, "vslm.ServiceInstanceContent", "vslm.ServiceInstanceContent"), "System.Anonymous", None)])
CreateDataType("vslm.ServiceInstanceContent", "VslmServiceInstanceContent", "vmodl.DynamicData", "vslm.version.version14", [("aboutInfo", "vslm.AboutInfo", "vslm.version.version14", 0), ("sessionManager", "vslm.auth.SessionManager", "vslm.version.version14", 0), ("vStorageObjectManager", "vslm.vso.VStorageObjectManager", "vslm.version.version14", 0), ("storageLifecycleManager", "vslm.StorageLifecycleManager", "vslm.version.version14", 0)])
CreateManagedType("vslm.StorageLifecycleManager", "VslmStorageLifecycleManager", "vmodl.ManagedObject", "vslm.version.version14", None, [("syncDatastore", "VslmSyncDatastore", "vslm.version.version14", (("datastoreUrl", "string", "vslm.version.version14", 0, None),("fullSync", "boolean", "vslm.version.version14", 0, None),("fcdId", "vim.vslm.ID", "vslm.version.version14", F_OPTIONAL, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.SyncFault", "vslm.fault.VslmFault", ]), ("queryDatastoreInfo", "VslmQueryDatastoreInfo", "vslm.version.version14", (("datastoreUrl", "string", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vslm.QueryDatastoreInfoResult[]", "vslm.QueryDatastoreInfoResult[]"), "System.View", ["vim.fault.NotFound", "vslm.fault.VslmFault", ])])
CreateManagedType("vslm.Task", "VslmTask", "vmodl.ManagedObject", "vslm.version.version14", None, [("queryResult", "VslmQueryTaskResult", "vslm.version.version14", (), (F_OPTIONAL, "anyType", "anyType"), None, None), ("queryInfo", "VslmQueryInfo", "vslm.version.version14", (), (0, "vslm.TaskInfo", "vslm.TaskInfo"), None, None), ("cancel", "VslmCancelTask", "vslm.version.version14", (), (0, "void", "void"), None, ["vim.fault.InvalidState", ])])
CreateDataType("vslm.TaskInfo", "VslmTaskInfo", "vmodl.DynamicData", "vslm.version.version14", [("key", "string", "vslm.version.version14", 0), ("task", "vslm.Task", "vslm.version.version14", 0), ("description", "vmodl.LocalizableMessage", "vslm.version.version14", F_OPTIONAL), ("name", "vmodl.MethodName", "vslm.version.version14", F_OPTIONAL), ("descriptionId", "string", "vslm.version.version14", 0), ("entity", "vim.ManagedEntity", "vslm.version.version14", F_OPTIONAL), ("entityName", "string", "vslm.version.version14", F_OPTIONAL), ("locked", "vim.ManagedEntity[]", "vslm.version.version14", F_OPTIONAL), ("state", "vslm.TaskInfo.State", "vslm.version.version14", 0), ("cancelled", "boolean", "vslm.version.version14", 0), ("cancelable", "boolean", "vslm.version.version14", 0), ("error", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL), ("result", "anyType", "vslm.version.version14", F_OPTIONAL), ("progress", "int", "vslm.version.version14", F_OPTIONAL), ("reason", "vslm.TaskReason", "vslm.version.version14", 0), ("queueTime", "vmodl.DateTime", "vslm.version.version14", 0), ("startTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("completeTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("eventChainId", "int", "vslm.version.version14", 0), ("changeTag", "string", "vslm.version.version14", F_OPTIONAL), ("parentTaskKey", "string", "vslm.version.version14", F_OPTIONAL), ("rootTaskKey", "string", "vslm.version.version14", F_OPTIONAL), ("activationId", "string", "vslm.version.version14", F_OPTIONAL)])
CreateEnumType("vslm.TaskInfo.State", "VslmTaskInfoState", "vslm.version.version14", ["queued", "running", "success", "error"])
CreateDataType("vslm.TaskReason", "VslmTaskReason", "vmodl.DynamicData", "vslm.version.version1", None)
CreateDataType("vslm.TaskReasonAlarm", "VslmTaskReasonAlarm", "vslm.TaskReason", "vslm.version.version1", [("alarmName", "string", "vslm.version.version1", 0), ("alarm", "vim.alarm.Alarm", "vslm.version.version1", 0), ("entityName", "string", "vslm.version.version1", 0), ("entity", "vim.ManagedEntity", "vslm.version.version1", 0)])
CreateDataType("vslm.TaskReasonSchedule", "VslmTaskReasonSchedule", "vslm.TaskReason", "vslm.version.version1", [("name", "string", "vslm.version.version1", 0), ("scheduledTask", "vim.scheduler.ScheduledTask", "vslm.version.version1", 0)])
CreateDataType("vslm.TaskReasonSystem", "VslmTaskReasonSystem", "vslm.TaskReason", "vslm.version.version1", None)
CreateDataType("vslm.TaskReasonUser", "VslmTaskReasonUser", "vslm.TaskReason", "vslm.version.version1", [("userName", "string", "vslm.version.version1", 0)])
CreateManagedType("vslm.auth.SessionManager", "VslmSessionManager", "vmodl.ManagedObject", "vslm.version.version14", None, [("loginByToken", "VslmLoginByToken", "vslm.version.version14", (("delegatedTokenXml", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.Anonymous", ["vim.fault.InvalidLogin", ]), ("logout", "VslmLogout", "vslm.version.version14", (), (0, "void", "void"), "StoragLifecycle.View", None)])
CreateEnumType("vslm.event.VslmEvent.VslmEventType", "VslmEventType", "vslm.version.version1", ["preFcdMigrateEvent", "postFcdMigrateEvent"])
CreateEnumType("vslm.event.VslmEventInfo.State", "VslmEventVslmEventInfoState", "vslm.version.version1", ["success", "error"])
CreateDataType("vslm.fault.VslmFault", "VslmFault", "vmodl.MethodFault", "vslm.version.version14", [("msg", "string", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.DatastoreSyncStatus", "VslmDatastoreSyncStatus", "vmodl.DynamicData", "vslm.version.version14", [("datastoreURL", "string", "vslm.version.version14", 0), ("objectVClock", "long", "vslm.version.version14", 0), ("syncVClock", "long", "vslm.version.version14", 0), ("syncTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("numberOfRetries", "int", "vslm.version.version14", F_OPTIONAL), ("error", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectAssociations", "VslmVsoVStorageObjectAssociations", "vmodl.DynamicData", "vslm.version.version14", [("id", "vim.vslm.ID", "vslm.version.version14", 0), ("vmDiskAssociation", "vslm.vso.VStorageObjectAssociations.VmDiskAssociation[]", "vslm.version.version14", F_OPTIONAL), ("fault", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectAssociations.VmDiskAssociation", "VslmVsoVStorageObjectAssociationsVmDiskAssociation", "vmodl.DynamicData", "vslm.version.version14", [("vmId", "string", "vslm.version.version14", 0), ("diskKey", "int", "vslm.version.version14", 0)])
CreateManagedType("vslm.vso.VStorageObjectManager", "VslmVStorageObjectManager", "vmodl.ManagedObject", "vslm.version.version14", None, [("createDisk", "VslmCreateDisk_Task", "vslm.version.version14", (("spec", "vim.vslm.CreateSpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vslm.fault.VslmFault", ]), ("registerDisk", "VslmRegisterDisk", "vslm.version.version14", (("path", "string", "vslm.version.version14", 0, None),("name", "string", "vslm.version.version14", F_OPTIONAL, None),), (0, "vim.vslm.VStorageObject", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.AlreadyExists", "vslm.fault.SyncFault", "vslm.fault.VslmFault", ]), ("extendDisk", "VslmExtendDisk_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("newCapacityInMB", "long", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.NotFound", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("inflateDisk", "VslmInflateDisk_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.NotFound", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("renameVStorageObject", "VslmRenameVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("name", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.SyncFault", "vslm.fault.VslmFault", ]), ("updateVStorageObjectPolicy", "VslmUpdateVstorageObjectPolicy_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("profile", "vim.vm.ProfileSpec[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("updateVStorageObjectCrypto", "VslmUpdateVstorageObjectCrypto_Task", "vslm.version.v7_0", (("id", "vim.vslm.ID", "vslm.version.v7_0", 0, None),("profile", "vim.vm.ProfileSpec[]", "vslm.version.v7_0", F_OPTIONAL, None),("disksCrypto", "vim.vslm.DiskCryptoSpec", "vslm.version.v7_0", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("updateVStorageInfrastructureObjectPolicy", "VslmUpdateVStorageInfrastructureObjectPolicy_Task", "vslm.version.version14", (("spec", "vim.vslm.InfrastructureObjectPolicySpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.InvalidState", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("retrieveVStorageInfrastructureObjectPolicy", "VslmRetrieveVStorageInfrastructureObjectPolicy", "vslm.version.version14", (("datastore", "vim.Datastore", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vim.vslm.InfrastructureObjectPolicy[]", "vim.vslm.InfrastructureObjectPolicy[]"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("deleteVStorageObject", "VslmDeleteVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vim.fault.TaskInProgress", "vslm.fault.VslmFault", ]), ("retrieveVStorageObject", "VslmRetrieveVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.VStorageObject", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectState", "VslmRetrieveVStorageObjectState", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.StateInfo", "vim.vslm.StateInfo"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectAssociations", "VslmRetrieveVStorageObjectAssociations", "vslm.version.version14", (("ids", "vim.vslm.ID[]", "vslm.version.version14", F_OPTIONAL, None),), (F_OPTIONAL, "vslm.vso.VStorageObjectAssociations[]", "vslm.vso.VStorageObjectAssociations[]"), "System.View", None), ("listVStorageObjectsForSpec", "VslmListVStorageObjectForSpec", "vslm.version.version14", (("query", "vslm.vso.VStorageObjectQuerySpec[]", "vslm.version.version14", F_OPTIONAL, None),("maxResult", "int", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vslm.vso.VStorageObjectQueryResult", "vslm.vso.VStorageObjectQueryResult"), "System.View", None), ("cloneVStorageObject", "VslmCloneVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("spec", "vim.vslm.CloneSpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("relocateVStorageObject", "VslmRelocateVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("spec", "vim.vslm.RelocateSpec", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.FileFault", "vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("setVStorageObjectControlFlags", "VslmSetVStorageObjectControlFlags", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("controlFlags", "string[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("clearVStorageObjectControlFlags", "VslmClearVStorageObjectControlFlags", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("controlFlags", "string[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("attachTagToVStorageObject", "VslmAttachTagToVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("category", "string", "vslm.version.version14", 0, None),("tag", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("detachTagFromVStorageObject", "VslmDetachTagFromVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("category", "string", "vslm.version.version14", 0, None),("tag", "string", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("listVStorageObjectsAttachedToTag", "VslmListVStorageObjectsAttachedToTag", "vslm.version.version14", (("category", "string", "vslm.version.version14", 0, None),("tag", "string", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vim.vslm.ID[]", "vim.vslm.ID[]"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("listTagsAttachedToVStorageObject", "VslmListTagsAttachedToVStorageObject", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vim.vslm.TagEntry[]", "vim.vslm.TagEntry[]"), "System.Read", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("reconcileDatastoreInventory", "VslmReconcileDatastoreInventory_Task", "vslm.version.version14", (("datastore", "vim.Datastore", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("scheduleReconcileDatastoreInventory", "VslmScheduleReconcileDatastoreInventory", "vslm.version.version14", (("datastore", "vim.Datastore", "vslm.version.version14", 0, None),), (0, "void", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("createSnapshot", "VslmCreateSnapshot_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("description", "string", "vslm.version.version14", 0, None),), (0, "vslm.Task", "vim.vslm.ID"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("deleteSnapshot", "VslmDeleteSnapshot_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("retrieveSnapshotInfo", "VslmRetrieveSnapshotInfo", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.VStorageObjectSnapshotInfo", "vim.vslm.VStorageObjectSnapshotInfo"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("createDiskFromSnapshot", "VslmCreateDiskFromSnapshot_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),("name", "string", "vslm.version.version14", 0, None),("profile", "vim.vm.ProfileSpec[]", "vslm.version.version14", F_OPTIONAL, None),("crypto", "vim.encryption.CryptoSpec", "vslm.version.version14", F_OPTIONAL, None),("path", "string", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "vim.vslm.VStorageObject"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("revertVStorageObject", "VslmRevertVStorageObject_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("retrieveSnapshotDetails", "VslmRetrieveSnapshotDetails", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),), (0, "vim.vslm.VStorageObjectSnapshotDetails", "vim.vslm.VStorageObjectSnapshotDetails"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vslm.fault.VslmFault", ]), ("queryChangedDiskAreas", "VslmQueryChangedDiskAreas", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", 0, None),("startOffset", "long", "vslm.version.version14", 0, None),("changeId", "string", "vslm.version.version14", 0, None),), (0, "vim.VirtualMachine.DiskChangeInfo", "vim.VirtualMachine.DiskChangeInfo"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.NotFound", "vim.fault.FileFault", "vim.fault.InvalidState", "vmodl.fault.InvalidArgument", "vslm.fault.VslmFault", ]), ("queryGlobalCatalogSyncStatus", "VslmQueryGlobalCatalogSyncStatus", "vslm.version.version14", (), (F_OPTIONAL, "vslm.vso.DatastoreSyncStatus[]", "vslm.vso.DatastoreSyncStatus[]"), "System.View", None), ("queryGlobalCatalogSyncStatusForDatastore", "VslmQueryGlobalCatalogSyncStatusForDatastore", "vslm.version.version14", (("datastoreURL", "string", "vslm.version.version14", 0, None),), (F_OPTIONAL, "vslm.vso.DatastoreSyncStatus", "vslm.vso.DatastoreSyncStatus"), "System.View", ["vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("updateVStorageObjectMetadata", "VslmUpdateVStorageObjectMetadata_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("metadata", "vim.KeyValue[]", "vslm.version.version14", F_OPTIONAL, None),("deleteKeys", "string[]", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectMetadata", "VslmRetrieveVStorageObjectMetadata", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", F_OPTIONAL, None),("prefix", "string", "vslm.version.version14", F_OPTIONAL, None),), (F_OPTIONAL, "vim.KeyValue[]", "vim.KeyValue[]"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjectMetadataValue", "VslmRetrieveVStorageObjectMetadataValue", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("snapshotId", "vim.vslm.ID", "vslm.version.version14", F_OPTIONAL, None),("key", "string", "vslm.version.version14", 0, None),), (0, "string", "string"), "System.View", ["vim.fault.InvalidDatastore", "vim.fault.InvalidState", "vim.fault.NotFound", "vim.fault.KeyNotFound", "vslm.fault.VslmFault", ]), ("retrieveVStorageObjects", "VslmRetrieveVStorageObjects", "vslm.version.version14", (("ids", "vim.vslm.ID[]", "vslm.version.version14", F_OPTIONAL, None),), (F_OPTIONAL, "vslm.vso.VStorageObjectResult[]", "vslm.vso.VStorageObjectResult[]"), "System.View", None), ("attachDisk", "VslmAttachDisk_Task", "vslm.version.version14", (("id", "vim.vslm.ID", "vslm.version.version14", 0, None),("vm", "vim.VirtualMachine", "vslm.version.version14", 0, None),("controllerKey", "int", "vslm.version.version14", F_OPTIONAL, None),("unitNumber", "int", "vslm.version.version14", F_OPTIONAL, None),), (0, "vslm.Task", "void"), "VirtualMachine.Config.AddExistingDisk", ["vim.fault.NotFound", "vim.fault.VmConfigFault", "vim.fault.FileFault", "vim.fault.InvalidState", "vim.fault.InvalidDatastore", "vim.fault.InvalidController", "vim.fault.MissingController", "vim.fault.DeviceUnsupportedForVmVersion", "vslm.fault.VslmFault", ])])
CreateDataType("vslm.vso.VStorageObjectQueryResult", "VslmVsoVStorageObjectQueryResult", "vmodl.DynamicData", "vslm.version.version14", [("allRecordsReturned", "boolean", "vslm.version.version14", 0), ("id", "vim.vslm.ID[]", "vslm.version.version14", F_OPTIONAL), ("queryResults", "vslm.vso.VStorageObjectResult[]", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectQuerySpec", "VslmVsoVStorageObjectQuerySpec", "vmodl.DynamicData", "vslm.version.version14", [("queryField", "string", "vslm.version.version14", 0), ("queryOperator", "string", "vslm.version.version14", 0), ("queryValue", "string[]", "vslm.version.version14", F_OPTIONAL)])
CreateEnumType("vslm.vso.VStorageObjectQuerySpec.QueryOperatorEnum", "VslmVsoVStorageObjectQuerySpecQueryOperatorEnum", "vslm.version.version14", ["equals", "notEquals", "lessThan", "greaterThan", "lessThanOrEqual", "greaterThanOrEqual", "contains", "startsWith", "endsWith"])
CreateEnumType("vslm.vso.VStorageObjectQuerySpec.QueryFieldEnum", "VslmVsoVStorageObjectQuerySpecQueryFieldEnum", "vslm.version.version14", ["id", "name", "capacity", "createTime", "backingObjectId", "datastoreMoId", "metadataKey", "metadataValue"])
CreateDataType("vslm.vso.VStorageObjectResult", "VslmVsoVStorageObjectResult", "vmodl.DynamicData", "vslm.version.version14", [("id", "vim.vslm.ID", "vslm.version.version14", 0), ("name", "string", "vslm.version.version14", F_OPTIONAL), ("capacityInMB", "long", "vslm.version.version14", 0), ("createTime", "vmodl.DateTime", "vslm.version.version14", F_OPTIONAL), ("datastoreUrl", "string", "vslm.version.version14", F_OPTIONAL), ("diskPath", "string", "vslm.version.v7_0_1_0", F_OPTIONAL), ("usedCapacityInMB", "long", "vslm.version.v7_0_1_0", F_OPTIONAL), ("backingObjectId", "vim.vslm.ID", "vslm.version.version15", F_OPTIONAL), ("snapshotInfo", "vslm.vso.VStorageObjectSnapshotResult[]", "vslm.version.version15", F_OPTIONAL), ("metadata", "vim.KeyValue[]", "vslm.version.version14", F_OPTIONAL), ("error", "vmodl.MethodFault", "vslm.version.version14", F_OPTIONAL)])
CreateDataType("vslm.vso.VStorageObjectSnapshotResult", "VslmVsoVStorageObjectSnapshotResult", "vmodl.DynamicData", "vslm.version.version15", [("backingObjectId", "vim.vslm.ID", "vslm.version.version15", 0), ("description", "string", "vslm.version.v7_0_2_0", F_OPTIONAL), ("snapshotId", "vim.vslm.ID", "vslm.version.v7_0_2_0", F_OPTIONAL), ("diskPath", "string", "vslm.version.v7_0_2_0", F_OPTIONAL)])
CreateDataType("vslm.fault.SyncFault", "VslmSyncFault", "vslm.fault.VslmFault", "vslm.version.version14", [("id", "vim.vslm.ID", "vslm.version.v7_0", F_OPTIONAL)])



from typing import List
from pyVmomi import vim, vmodl
from pyVmomi.VmomiSupport import NoneType, long


class VStorageObjectManager(vim.vslm.VStorageObjectManagerBase):
    def CreateDisk(self, spec: vim.vslm.CreateSpec) -> vim.Task: ...
    def RegisterDisk(self, path: str, name: str) -> vim.vslm.VStorageObject: ...
    def ExtendDisk(self, id: vim.vslm.ID, datastore: vim.Datastore, newCapacityInMB: long) -> vim.Task: ...
    def InflateDisk(self, id: vim.vslm.ID, datastore: vim.Datastore) -> vim.Task: ...
    def RenameVStorageObject(self, id: vim.vslm.ID, datastore: vim.Datastore, name: str) -> NoneType: ...
    def UpdateVStorageObjectPolicy(self, id: vim.vslm.ID, datastore: vim.Datastore, profile: List[vim.vm.ProfileSpec]) -> vim.Task: ...
    def UpdateVStorageObjectCrypto(self, id: vim.vslm.ID, datastore: vim.Datastore, profile: List[vim.vm.ProfileSpec], disksCrypto: vim.vslm.DiskCryptoSpec) -> vim.Task: ...
    def UpdateVStorageInfrastructureObjectPolicy(self, spec: vim.vslm.InfrastructureObjectPolicySpec) -> vim.Task: ...
    def RetrieveVStorageInfrastructureObjectPolicy(self, datastore: vim.Datastore) -> List[vim.vslm.InfrastructureObjectPolicy]: ...
    def DeleteVStorageObject(self, id: vim.vslm.ID, datastore: vim.Datastore) -> vim.Task: ...
    def RetrieveVStorageObject(self, id: vim.vslm.ID, datastore: vim.Datastore, diskInfoFlags: List[str]) -> vim.vslm.VStorageObject: ...
    def RetrieveVStorageObjectState(self, id: vim.vslm.ID, datastore: vim.Datastore) -> vim.vslm.StateInfo: ...
    def RetrieveVStorageObjectAssociations(self, ids: List[RetrieveVStorageObjSpec]) -> List[VStorageObjectAssociations]: ...
    def ListVStorageObject(self, datastore: vim.Datastore) -> List[vim.vslm.ID]: ...
    def CloneVStorageObject(self, id: vim.vslm.ID, datastore: vim.Datastore, spec: vim.vslm.CloneSpec) -> vim.Task: ...
    def RelocateVStorageObject(self, id: vim.vslm.ID, datastore: vim.Datastore, spec: vim.vslm.RelocateSpec) -> vim.Task: ...
    def SetVStorageObjectControlFlags(self, id: vim.vslm.ID, datastore: vim.Datastore, controlFlags: List[str]) -> NoneType: ...
    def ClearVStorageObjectControlFlags(self, id: vim.vslm.ID, datastore: vim.Datastore, controlFlags: List[str]) -> NoneType: ...
    def AttachTagToVStorageObject(self, id: vim.vslm.ID, category: str, tag: str) -> NoneType: ...
    def DetachTagFromVStorageObject(self, id: vim.vslm.ID, category: str, tag: str) -> NoneType: ...
    def ListVStorageObjectsAttachedToTag(self, category: str, tag: str) -> List[vim.vslm.ID]: ...
    def ListTagsAttachedToVStorageObject(self, id: vim.vslm.ID) -> List[vim.vslm.TagEntry]: ...
    def ReconcileDatastoreInventory(self, datastore: vim.Datastore) -> vim.Task: ...
    def ScheduleReconcileDatastoreInventory(self, datastore: vim.Datastore) -> NoneType: ...
    def CreateSnapshot(self, id: vim.vslm.ID, datastore: vim.Datastore, description: str) -> vim.Task: ...
    def DeleteSnapshot(self, id: vim.vslm.ID, datastore: vim.Datastore, snapshotId: vim.vslm.ID) -> vim.Task: ...
    def RetrieveSnapshotInfo(self, id: vim.vslm.ID, datastore: vim.Datastore) -> vim.vslm.VStorageObjectSnapshotInfo: ...
    def CreateDiskFromSnapshot(self, id: vim.vslm.ID, datastore: vim.Datastore, snapshotId: vim.vslm.ID, name: str, profile: List[vim.vm.ProfileSpec], crypto: vim.encryption.CryptoSpec, path: str) -> vim.Task: ...
    def RevertVStorageObject(self, id: vim.vslm.ID, datastore: vim.Datastore, snapshotId: vim.vslm.ID) -> vim.Task: ...
    def RetrieveSnapshotDetails(self, id: vim.vslm.ID, datastore: vim.Datastore, snapshotId: vim.vslm.ID) -> vim.vslm.VStorageObjectSnapshotDetails: ...
    def QueryChangedDiskAreas(self, id: vim.vslm.ID, datastore: vim.Datastore, snapshotId: vim.vslm.ID, startOffset: long, changeId: str) -> vim.VirtualMachine.DiskChangeInfo: ...
    def DeleteVStorageObjectEx(self, id: vim.vslm.ID, datastore: vim.Datastore) -> vim.Task: ...
    def UpdateVStorageObjectMetadataEx(self, id: vim.vslm.ID, datastore: vim.Datastore, metadata: List[vim.KeyValue], deleteKeys: List[str]) -> vim.Task: ...


class RetrieveVStorageObjSpec(vmodl.DynamicData):
    @property
    def id(self) -> vim.vslm.ID: ...
    @id.setter
    def id(self, value: vim.vslm.ID):
        self._id = value
    @property
    def datastore(self) -> vim.Datastore: ...
    @datastore.setter
    def datastore(self, value: vim.Datastore):
        self._datastore = value


class VStorageObjectAssociations(vmodl.DynamicData):
    @property
    def id(self) -> vim.vslm.ID: ...
    @id.setter
    def id(self, value: vim.vslm.ID):
        self._id = value
    @property
    def vmDiskAssociations(self) -> List[VStorageObjectAssociations.VmDiskAssociations]: ...
    @vmDiskAssociations.setter
    def vmDiskAssociations(self, value: List[VStorageObjectAssociations.VmDiskAssociations]):
        self._vmDiskAssociations = value
    @property
    def fault(self) -> vmodl.MethodFault: ...
    @fault.setter
    def fault(self, value: vmodl.MethodFault):
        self._fault = value


    class VmDiskAssociations(vmodl.DynamicData):
        @property
        def vmId(self) -> str: ...
        @vmId.setter
        def vmId(self, value: str):
            self._vmId = value
        @property
        def diskKey(self) -> int: ...
        @diskKey.setter
        def diskKey(self, value: int):
            self._diskKey = value


# **********************************************************
# Copyright (c) 2008-2022 VMware, Inc.
# **********************************************************
# Diff any two objects

import logging

import six
from six.moves import zip

from .VmomiSupport import F_LINK, F_OPTIONAL, GetWsdlName, Type, types

__Log__ = logging.getLogger('ObjDiffer')


def LogIf(condition, message):
    """Log a message if the condition is met"""
    if condition:
        __Log__.debug(message)


def IsPrimitiveType(obj):
    """See if the passed in type is a Primitive Type"""
    return (isinstance(obj, types.bool) or isinstance(obj, types.byte)
            or isinstance(obj, types.short)
            or isinstance(obj, six.integer_types)
            or isinstance(obj, types.double) or isinstance(obj, types.float)
            or isinstance(obj, six.string_types)
            or isinstance(obj, types.PropertyPath)
            or isinstance(obj, types.ManagedMethod)
            or isinstance(obj, types.datetime) or isinstance(obj, types.URI)
            or isinstance(obj, types.binary) or isinstance(obj, type))


class Differ:
    """Class for comparing two Objects"""
    def __init__(self, looseMatch=False, ignoreArrayOrder=True):
        self._looseMatch = looseMatch
        self._ignoreArrayOrder = ignoreArrayOrder

    def DiffAnyObjects(self, oldObj, newObj, isObjLink=False):
        """Diff any two Objects"""
        if oldObj == newObj:
            return True
        if not oldObj or not newObj:
            __Log__.debug('DiffAnyObjects: One of the objects is unset.')
            return self._looseMatch
        oldObjInstance = oldObj
        newObjInstance = newObj
        if isinstance(oldObj, list):
            oldObjInstance = oldObj[0]
        if isinstance(newObj, list):
            newObjInstance = newObj[0]
        # Need to see if it is a primitive type first since type information
        #   will not be available for them.
        if (IsPrimitiveType(oldObj) and IsPrimitiveType(newObj)
                and oldObj.__class__.__name__ == newObj.__class__.__name__):
            if oldObj == newObj:
                return True
            elif oldObj is None or newObj is None:
                __Log__.debug('DiffAnyObjects: One of the objects in None')
            return False
        oldType = Type(oldObjInstance)
        newType = Type(newObjInstance)
        if oldType != newType:
            __Log__.debug('DiffAnyObjects: Types do not match %s != %s',
                          repr(GetWsdlName(oldObjInstance.__class__)),
                          repr(GetWsdlName(newObjInstance.__class__)))
            return False
        elif isinstance(oldObj, list):
            return self.DiffArrayObjects(oldObj, newObj, isObjLink)
        elif isinstance(oldObjInstance, types.ManagedObject):
            return (not oldObj
                    and not newObj) or (oldObj and newObj
                                        and oldObj._moId == newObj._moId)
        elif isinstance(oldObjInstance, types.DataObject):
            if isObjLink:
                bMatch = oldObj.GetKey() == newObj.GetKey()
                LogIf(
                    not bMatch, 'DiffAnyObjects: Keys do not match %s != %s' %
                    (oldObj.GetKey(), newObj.GetKey()))
                return bMatch
            return self.DiffDataObjects(oldObj, newObj)

        else:
            raise TypeError("Unknown type: " +
                            repr(GetWsdlName(oldObj.__class__)))

    def DiffDoArrays(self, oldObj, newObj, isElementLinks):
        """Diff two DataObject arrays"""
        if len(oldObj) != len(newObj):
            __Log__.debug('DiffDoArrays: Array lengths do not match %d != %d',
                          len(oldObj), len(newObj))
            return False
        for i, j in zip(oldObj, newObj):
            if isElementLinks:
                if i.GetKey() != j.GetKey():
                    __Log__.debug('DiffDoArrays: Keys do not match %s != %s',
                                  i.GetKey(), j.GetKey())
                    return False
            else:
                if not self.DiffDataObjects(i, j):
                    __Log__.debug(
                        'DiffDoArrays: one of the elements do not match')
                    return False
        return True

    def DiffAnyArrays(self, oldObj, newObj, isElementLinks):
        """Diff two arrays which contain Any objects"""
        if len(oldObj) != len(newObj):
            __Log__.debug(
                'DiffAnyArrays: Array lengths do not match. %d != %d',
                len(oldObj), len(newObj))
            return False
        for i, j in zip(oldObj, newObj):
            if not self.DiffAnyObjects(i, j, isElementLinks):
                __Log__.debug(
                    'DiffAnyArrays: One of the elements do not match.')
                return False
        return True

    def DiffPrimitiveArrays(self, oldObj, newObj):
        """Diff two primitive arrays"""
        if len(oldObj) != len(newObj):
            __Log__.debug('DiffDoArrays: Array lengths do not match %d != %d',
                          len(oldObj), len(newObj))
            return False
        match = True
        if self._ignoreArrayOrder:
            oldSet = oldObj and frozenset(oldObj) or frozenset()
            newSet = newObj and frozenset(newObj) or frozenset()
            match = (oldSet == newSet)
        else:
            for i, j in zip(oldObj, newObj):
                if i != j:
                    match = False
                    break
        if not match:
            __Log__.debug(
                'DiffPrimitiveArrays: One of the elements do not match.')
            return False
        return True

    def DiffArrayObjects(self, oldObj, newObj, isElementLinks=False):
        """Method which deligates the diffing of arrays based on the type"""
        if oldObj == newObj:
            return True
        if not oldObj or not newObj:
            return False
        if len(oldObj) != len(newObj):
            __Log__.debug(
                'DiffArrayObjects: Array lengths do not match %d != %d',
                len(oldObj), len(newObj))
            return False
        firstObj = oldObj[0]
        if IsPrimitiveType(firstObj):
            return self.DiffPrimitiveArrays(oldObj, newObj)
        elif isinstance(firstObj, types.ManagedObject):
            return self.DiffAnyArrays(oldObj, newObj, isElementLinks)
        elif isinstance(firstObj, types.DataObject):
            return self.DiffDoArrays(oldObj, newObj, isElementLinks)
        else:
            raise TypeError("Unknown type: {0}".format(oldObj.__class__))

    def DiffDataObjects(self, oldObj, newObj):
        """Diff Data Objects"""
        if oldObj == newObj:
            return True
        if not oldObj or not newObj:
            __Log__.debug('DiffDataObjects: One of the objects in None')
            return False
        oldType = Type(oldObj)
        newType = Type(newObj)
        if oldType != newType:
            __Log__.debug(
                'DiffDataObjects: Types do not match for dataobjects. '
                '%s != %s', oldObj._wsdlName, newObj._wsdlName)
            return False
        for prop in oldObj._GetPropertyList():
            oldProp = getattr(oldObj, prop.name)
            newProp = getattr(newObj, prop.name)
            propType = oldObj._GetPropertyInfo(prop.name).type
            if not oldProp and not newProp:
                continue
            elif ((prop.flags & F_OPTIONAL) and self._looseMatch
                  and (not newProp or not oldProp)):
                continue
            elif not oldProp or not newProp:
                __Log__.debug(
                    'DiffDataObjects: One of the objects has '
                    'the property %s unset', prop.name)
                return False

            bMatch = True
            if IsPrimitiveType(oldProp):
                bMatch = oldProp == newProp
            elif isinstance(oldProp, types.ManagedObject):
                bMatch = self.DiffAnyObjects(oldProp, newProp, prop.flags
                                             & F_LINK)
            elif isinstance(oldProp, types.DataObject):
                if prop.flags & F_LINK:
                    bMatch = oldObj.GetKey() == newObj.GetKey()
                    LogIf(
                        not bMatch,
                        'DiffDataObjects: Key match failed %s != %s' %
                        (oldObj.GetKey(), newObj.GetKey()))
                else:
                    bMatch = self.DiffAnyObjects(oldProp, newProp, prop.flags
                                                 & F_LINK)
            elif isinstance(oldProp, list):
                bMatch = self.DiffArrayObjects(oldProp, newProp,
                                               prop.flags & F_LINK)
            else:
                raise TypeError("Unknown type: " + repr(propType))

            if not bMatch:
                __Log__.debug('DiffDataObjects: Objects differ in property %s',
                              prop.name)
                return False
        return True


def DiffAnys(obj1, obj2, looseMatch=False, ignoreArrayOrder=True):
    """Diff any two objects. Objects can either be primitive type
    or DataObjects
    """
    differ = Differ(looseMatch=looseMatch, ignoreArrayOrder=ignoreArrayOrder)
    return differ.DiffAnyObjects(obj1, obj2)



from typing import List
from pyVmomi import vim
from pyVmomi.VmomiSupport import ManagedObject, NoneType


class ContainerView(ManagedObjectView):
    @property
    def container(self) -> vim.ManagedEntity: ...
    @property
    def type(self) -> List[type]: ...
    @property
    def recursive(self) -> bool: ...


class InventoryView(ManagedObjectView):
    def OpenFolder(self, entity: List[vim.ManagedEntity]) -> List[vim.ManagedEntity]: ...
    def CloseFolder(self, entity: List[vim.ManagedEntity]) -> List[vim.ManagedEntity]: ...


class ListView(ManagedObjectView):
    def Modify(self, add: List[ManagedObject], remove: List[ManagedObject]) -> List[ManagedObject]: ...
    def Reset(self, obj: List[ManagedObject]) -> List[ManagedObject]: ...
    def ResetFromView(self, view: View) -> NoneType: ...


class ManagedObjectView(View):
    @property
    def view(self) -> List[ManagedObject]: ...


class View(ManagedObject):
    def Destroy(self) -> NoneType: ...


class ViewManager(ManagedObject):
    @property
    def viewList(self) -> List[View]: ...
    def CreateInventoryView(self) -> InventoryView: ...
    def CreateContainerView(self, container: vim.ManagedEntity, type: List[type], recursive: bool) -> ContainerView: ...
    def CreateListView(self, obj: List[ManagedObject]) -> ListView: ...
    def CreateListViewFromView(self, view: View) -> ListView: ...


from typing import List
from enum import Enum
from pyVmomi import vim, vmodl
from datetime import datetime
from pyVmomi.VmomiSupport import ManagedObject, long
from . import host as host
from . import vcenter as vcenter


class VStorageObjectManagerBase(ManagedObject):
    def ExtendDiskEx(self, id: ID, datastore: vim.Datastore, newCapacityInMB: long) -> vim.Task: ...
    def RenameVStorageObjectEx(self, id: ID, datastore: vim.Datastore, name: str) -> VClockInfo: ...
    def CreateSnapshotEx(self, id: ID, datastore: vim.Datastore, description: str) -> vim.Task: ...
    def DeleteSnapshotEx(self, id: ID, datastore: vim.Datastore, snapshotId: ID) -> vim.Task: ...
    def RevertVStorageObjectEx(self, id: ID, datastore: vim.Datastore, snapshotId: ID) -> vim.Task: ...


class BaseConfigInfo(vmodl.DynamicData):
    @property
    def id(self) -> ID: ...
    @id.setter
    def id(self, value: ID):
        self._id = value
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def createTime(self) -> datetime: ...
    @createTime.setter
    def createTime(self, value: datetime):
        self._createTime = value
    @property
    def keepAfterDeleteVm(self) -> bool: ...
    @keepAfterDeleteVm.setter
    def keepAfterDeleteVm(self, value: bool):
        self._keepAfterDeleteVm = value
    @property
    def relocationDisabled(self) -> bool: ...
    @relocationDisabled.setter
    def relocationDisabled(self, value: bool):
        self._relocationDisabled = value
    @property
    def nativeSnapshotSupported(self) -> bool: ...
    @nativeSnapshotSupported.setter
    def nativeSnapshotSupported(self, value: bool):
        self._nativeSnapshotSupported = value
    @property
    def changedBlockTrackingEnabled(self) -> bool: ...
    @changedBlockTrackingEnabled.setter
    def changedBlockTrackingEnabled(self, value: bool):
        self._changedBlockTrackingEnabled = value
    @property
    def backing(self) -> BaseConfigInfo.BackingInfo: ...
    @backing.setter
    def backing(self, value: BaseConfigInfo.BackingInfo):
        self._backing = value
    @property
    def metadata(self) -> List[vim.KeyValue]: ...
    @metadata.setter
    def metadata(self, value: List[vim.KeyValue]):
        self._metadata = value
    @property
    def vclock(self) -> VClockInfo: ...
    @vclock.setter
    def vclock(self, value: VClockInfo):
        self._vclock = value
    @property
    def iofilter(self) -> List[str]: ...
    @iofilter.setter
    def iofilter(self, value: List[str]):
        self._iofilter = value


    class BackingInfo(vmodl.DynamicData):
        @property
        def datastore(self) -> vim.Datastore: ...
        @datastore.setter
        def datastore(self, value: vim.Datastore):
            self._datastore = value


    class DiskFileBackingInfo(BaseConfigInfo.FileBackingInfo):
        @property
        def provisioningType(self) -> str: ...
        @provisioningType.setter
        def provisioningType(self, value: str):
            self._provisioningType = value


        class ProvisioningType(Enum):
            thin = "thin"
            eagerZeroedThick = "eagerZeroedThick"
            lazyZeroedThick = "lazyZeroedThick"


    class FileBackingInfo(BaseConfigInfo.BackingInfo):
        @property
        def filePath(self) -> str: ...
        @filePath.setter
        def filePath(self, value: str):
            self._filePath = value
        @property
        def backingObjectId(self) -> str: ...
        @backingObjectId.setter
        def backingObjectId(self, value: str):
            self._backingObjectId = value
        @property
        def parent(self) -> BaseConfigInfo.FileBackingInfo: ...
        @parent.setter
        def parent(self, value: BaseConfigInfo.FileBackingInfo):
            self._parent = value
        @property
        def deltaSizeInMB(self) -> long: ...
        @deltaSizeInMB.setter
        def deltaSizeInMB(self, value: long):
            self._deltaSizeInMB = value
        @property
        def keyId(self) -> vim.encryption.CryptoKeyId: ...
        @keyId.setter
        def keyId(self, value: vim.encryption.CryptoKeyId):
            self._keyId = value


    class RawDiskMappingBackingInfo(BaseConfigInfo.FileBackingInfo):
        @property
        def lunUuid(self) -> str: ...
        @lunUuid.setter
        def lunUuid(self, value: str):
            self._lunUuid = value
        @property
        def compatibilityMode(self) -> str: ...
        @compatibilityMode.setter
        def compatibilityMode(self, value: str):
            self._compatibilityMode = value


class CloneSpec(MigrateSpec):
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def keepAfterDeleteVm(self) -> bool: ...
    @keepAfterDeleteVm.setter
    def keepAfterDeleteVm(self, value: bool):
        self._keepAfterDeleteVm = value
    @property
    def metadata(self) -> List[vim.KeyValue]: ...
    @metadata.setter
    def metadata(self, value: List[vim.KeyValue]):
        self._metadata = value


class CreateSpec(vmodl.DynamicData):
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def keepAfterDeleteVm(self) -> bool: ...
    @keepAfterDeleteVm.setter
    def keepAfterDeleteVm(self, value: bool):
        self._keepAfterDeleteVm = value
    @property
    def backingSpec(self) -> CreateSpec.BackingSpec: ...
    @backingSpec.setter
    def backingSpec(self, value: CreateSpec.BackingSpec):
        self._backingSpec = value
    @property
    def capacityInMB(self) -> long: ...
    @capacityInMB.setter
    def capacityInMB(self, value: long):
        self._capacityInMB = value
    @property
    def profile(self) -> List[vim.vm.ProfileSpec]: ...
    @profile.setter
    def profile(self, value: List[vim.vm.ProfileSpec]):
        self._profile = value
    @property
    def crypto(self) -> vim.encryption.CryptoSpec: ...
    @crypto.setter
    def crypto(self, value: vim.encryption.CryptoSpec):
        self._crypto = value
    @property
    def metadata(self) -> List[vim.KeyValue]: ...
    @metadata.setter
    def metadata(self, value: List[vim.KeyValue]):
        self._metadata = value


    class BackingSpec(vmodl.DynamicData):
        @property
        def datastore(self) -> vim.Datastore: ...
        @datastore.setter
        def datastore(self, value: vim.Datastore):
            self._datastore = value
        @property
        def path(self) -> str: ...
        @path.setter
        def path(self, value: str):
            self._path = value


    class DiskFileBackingSpec(CreateSpec.BackingSpec):
        @property
        def provisioningType(self) -> str: ...
        @provisioningType.setter
        def provisioningType(self, value: str):
            self._provisioningType = value


    class RawDiskMappingBackingSpec(CreateSpec.BackingSpec):
        @property
        def lunUuid(self) -> str: ...
        @lunUuid.setter
        def lunUuid(self, value: str):
            self._lunUuid = value
        @property
        def compatibilityMode(self) -> str: ...
        @compatibilityMode.setter
        def compatibilityMode(self, value: str):
            self._compatibilityMode = value


class DiskCryptoSpec(vmodl.DynamicData):
    @property
    def parent(self) -> DiskCryptoSpec: ...
    @parent.setter
    def parent(self, value: DiskCryptoSpec):
        self._parent = value
    @property
    def crypto(self) -> vim.encryption.CryptoSpec: ...
    @crypto.setter
    def crypto(self, value: vim.encryption.CryptoSpec):
        self._crypto = value


class ID(vmodl.DynamicData):
    @property
    def id(self) -> str: ...
    @id.setter
    def id(self, value: str):
        self._id = value


class InfrastructureObjectPolicy(vmodl.DynamicData):
    @property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str):
        self._name = value
    @property
    def backingObjectId(self) -> str: ...
    @backingObjectId.setter
    def backingObjectId(self, value: str):
        self._backingObjectId = value
    @property
    def profileId(self) -> str: ...
    @profileId.setter
    def profileId(self, value: str):
        self._profileId = value
    @property
    def error(self) -> vmodl.MethodFault: ...
    @error.setter
    def error(self, value: vmodl.MethodFault):
        self._error = value


class InfrastructureObjectPolicySpec(vmodl.DynamicData):
    @property
    def datastore(self) -> vim.Datastore: ...
    @datastore.setter
    def datastore(self, value: vim.Datastore):
        self._datastore = value
    @property
    def profile(self) -> List[vim.vm.ProfileSpec]: ...
    @profile.setter
    def profile(self, value: List[vim.vm.ProfileSpec]):
        self._profile = value


class MigrateSpec(vmodl.DynamicData):
    @property
    def backingSpec(self) -> CreateSpec.BackingSpec: ...
    @backingSpec.setter
    def backingSpec(self, value: CreateSpec.BackingSpec):
        self._backingSpec = value
    @property
    def profile(self) -> List[vim.vm.ProfileSpec]: ...
    @profile.setter
    def profile(self, value: List[vim.vm.ProfileSpec]):
        self._profile = value
    @property
    def consolidate(self) -> bool: ...
    @consolidate.setter
    def consolidate(self, value: bool):
        self._consolidate = value
    @property
    def disksCrypto(self) -> DiskCryptoSpec: ...
    @disksCrypto.setter
    def disksCrypto(self, value: DiskCryptoSpec):
        self._disksCrypto = value


class RelocateSpec(MigrateSpec): ...


class StateInfo(vmodl.DynamicData):
    @property
    def tentative(self) -> bool: ...
    @tentative.setter
    def tentative(self, value: bool):
        self._tentative = value


class TagEntry(vmodl.DynamicData):
    @property
    def tagName(self) -> str: ...
    @tagName.setter
    def tagName(self, value: str):
        self._tagName = value
    @property
    def parentCategoryName(self) -> str: ...
    @parentCategoryName.setter
    def parentCategoryName(self, value: str):
        self._parentCategoryName = value


class VClockInfo(vmodl.DynamicData):
    @property
    def vClockTime(self) -> long: ...
    @vClockTime.setter
    def vClockTime(self, value: long):
        self._vClockTime = value


class VStorageObject(vmodl.DynamicData):
    @property
    def config(self) -> VStorageObject.ConfigInfo: ...
    @config.setter
    def config(self, value: VStorageObject.ConfigInfo):
        self._config = value


    class ConfigInfo(BaseConfigInfo):
        @property
        def descriptorVersion(self) -> int: ...
        @descriptorVersion.setter
        def descriptorVersion(self, value: int):
            self._descriptorVersion = value
        @property
        def capacityInMB(self) -> long: ...
        @capacityInMB.setter
        def capacityInMB(self, value: long):
            self._capacityInMB = value
        @property
        def consumptionType(self) -> List[str]: ...
        @consumptionType.setter
        def consumptionType(self, value: List[str]):
            self._consumptionType = value
        @property
        def consumerId(self) -> List[ID]: ...
        @consumerId.setter
        def consumerId(self, value: List[ID]):
            self._consumerId = value


    class ConsumptionType(Enum):
        disk = "disk"


class VStorageObjectSnapshot(vmodl.DynamicData):
    @property
    def id(self) -> ID: ...
    @id.setter
    def id(self, value: ID):
        self._id = value
    @property
    def vclock(self) -> VClockInfo: ...
    @vclock.setter
    def vclock(self, value: VClockInfo):
        self._vclock = value


class VStorageObjectSnapshotDetails(vmodl.DynamicData):
    @property
    def path(self) -> str: ...
    @path.setter
    def path(self, value: str):
        self._path = value
    @property
    def changedBlockTrackingId(self) -> str: ...
    @changedBlockTrackingId.setter
    def changedBlockTrackingId(self, value: str):
        self._changedBlockTrackingId = value


class VStorageObjectSnapshotInfo(vmodl.DynamicData):
    @property
    def snapshots(self) -> List[VStorageObjectSnapshotInfo.VStorageObjectSnapshot]: ...
    @snapshots.setter
    def snapshots(self, value: List[VStorageObjectSnapshotInfo.VStorageObjectSnapshot]):
        self._snapshots = value


    class VStorageObjectSnapshot(vmodl.DynamicData):
        @property
        def id(self) -> ID: ...
        @id.setter
        def id(self, value: ID):
            self._id = value
        @property
        def backingObjectId(self) -> str: ...
        @backingObjectId.setter
        def backingObjectId(self, value: str):
            self._backingObjectId = value
        @property
        def createTime(self) -> datetime: ...
        @createTime.setter
        def createTime(self, value: datetime):
            self._createTime = value
        @property
        def description(self) -> str: ...
        @description.setter
        def description(self, value: str):
            self._description = value


from typing import List
from pyVmomi import eam, vim


class CannotConfigureSolutions(PMIssue):
    @property
    def cr(self) -> vim.ComputeResource: ...
    @cr.setter
    def cr(self, value: vim.ComputeResource):
        self._cr = value
    @property
    def solutionsToModify(self) -> List[str]: ...
    @solutionsToModify.setter
    def solutionsToModify(self, value: List[str]):
        self._solutionsToModify = value
    @property
    def solutionsToRemove(self) -> List[str]: ...
    @solutionsToRemove.setter
    def solutionsToRemove(self, value: List[str]):
        self._solutionsToRemove = value


class CannotUploadDepot(DepotIssue):
    @property
    def localDepotUrl(self) -> str: ...
    @localDepotUrl.setter
    def localDepotUrl(self, value: str):
        self._localDepotUrl = value


class DepotIssue(PMIssue):
    @property
    def remoteDepotUrl(self) -> str: ...
    @remoteDepotUrl.setter
    def remoteDepotUrl(self, value: str):
        self._remoteDepotUrl = value


class InaccessibleDepot(DepotIssue): ...


class InvalidDepot(DepotIssue): ...


class PMIssue(eam.issue.AgencyIssue): ...


class PMUnavailable(PMIssue): ...


from typing import List, Literal
from enum import Enum
from pyVmomi import vim, vmodl
from pyVmomi.VmomiSupport import ManagedObject, NoneType, long


class OptionManager(ManagedObject):
    @property
    def supportedOption(self) -> List[OptionDef]: ...
    @property
    def setting(self) -> List[OptionValue]: ...
    def QueryView(self, name: str) -> List[OptionValue]: ...
    def UpdateValues(self, changedValue: List[OptionValue]) -> NoneType: ...


class ArrayUpdateSpec(vmodl.DynamicData):
    @property
    def operation(self) -> ArrayUpdateSpec.Operation | Literal['add', 'remove', 'edit']: ...
    @operation.setter
    def operation(self, value: ArrayUpdateSpec.Operation | Literal['add', 'remove', 'edit']):
        self._operation = value
    @property
    def removeKey(self) -> object: ...
    @removeKey.setter
    def removeKey(self, value: object):
        self._removeKey = value


    class Operation(Enum):
        add = "add"
        remove = "remove"
        edit = "edit"


class BoolOption(OptionType):
    @property
    def supported(self) -> bool: ...
    @supported.setter
    def supported(self, value: bool):
        self._supported = value
    @property
    def defaultValue(self) -> bool: ...
    @defaultValue.setter
    def defaultValue(self, value: bool):
        self._defaultValue = value


class ChoiceOption(OptionType):
    @property
    def choiceInfo(self) -> List[vim.ElementDescription]: ...
    @choiceInfo.setter
    def choiceInfo(self, value: List[vim.ElementDescription]):
        self._choiceInfo = value
    @property
    def defaultIndex(self) -> int: ...
    @defaultIndex.setter
    def defaultIndex(self, value: int):
        self._defaultIndex = value


class FloatOption(OptionType):
    @property
    def min(self) -> float: ...
    @min.setter
    def min(self, value: float):
        self._min = value
    @property
    def max(self) -> float: ...
    @max.setter
    def max(self, value: float):
        self._max = value
    @property
    def defaultValue(self) -> float: ...
    @defaultValue.setter
    def defaultValue(self, value: float):
        self._defaultValue = value


class IntOption(OptionType):
    @property
    def min(self) -> int: ...
    @min.setter
    def min(self, value: int):
        self._min = value
    @property
    def max(self) -> int: ...
    @max.setter
    def max(self, value: int):
        self._max = value
    @property
    def defaultValue(self) -> int: ...
    @defaultValue.setter
    def defaultValue(self, value: int):
        self._defaultValue = value


class LongOption(OptionType):
    @property
    def min(self) -> long: ...
    @min.setter
    def min(self, value: long):
        self._min = value
    @property
    def max(self) -> long: ...
    @max.setter
    def max(self, value: long):
        self._max = value
    @property
    def defaultValue(self) -> long: ...
    @defaultValue.setter
    def defaultValue(self, value: long):
        self._defaultValue = value


class OptionDef(vim.ElementDescription):
    @property
    def optionType(self) -> OptionType: ...
    @optionType.setter
    def optionType(self, value: OptionType):
        self._optionType = value


class OptionType(vmodl.DynamicData):
    @property
    def valueIsReadonly(self) -> bool: ...
    @valueIsReadonly.setter
    def valueIsReadonly(self, value: bool):
        self._valueIsReadonly = value


class OptionValue(vmodl.DynamicData):
    @property
    def key(self) -> str: ...
    @key.setter
    def key(self, value: str):
        self._key = value
    @property
    def value(self) -> object: ...
    @value.setter
    def value(self, value: object):
        self._value = value


class StringOption(OptionType):
    @property
    def defaultValue(self) -> str: ...
    @defaultValue.setter
    def defaultValue(self, value: str):
        self._defaultValue = value
    @property
    def validCharacters(self) -> str: ...
    @validCharacters.setter
    def validCharacters(self, value: str):
        self._validCharacters = value